package sample;

import java.io.PrintStream;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.Statement;
import java.time.LocalDate;
import java.util.Optional;

import sample.dao.CompanyDao;
import sample.dao.CompanyDaoImpl;
import sample.dao.PersonDao;
import sample.dao.PersonDaoImpl;
import sample.domain.Address;
import sample.domain.PhoneNumber;
import sample.entity.Company;
import sample.entity.Person;

/**
 * サンプルコードのメインクラスです。
 * EclipseなどのIDEでこのクラスを実行してください。
 *
 */
public class SampleMain {

    public static void main(String[] args) throws SQLException {

        setUpDB();

        PrintStream out = System.err;

        //PersonをSELECTして、誕生日をUPDATEして、再度SELECTする 

        PersonDao personDao = new PersonDaoImpl();

        Person person1 = personDao.selectById(100L);

        out.println("**** 1 *******************************");
        out.printf("%s: %s (%s)%n",
                person1.id,
                person1.name,
                person1.birthday);
        out.println("**************************************");

        person1.birthday = LocalDate.of(1984, 2, 10);
        personDao.update(person1);

        Person person2 = personDao.selectById(100L);

        out.println("**** 2 *******************************");
        out.printf("%s: %s (%s)%n",
                person2.id,
                person2.name,
                person2.birthday);
        out.println("**************************************");

        //ドメインクラスの利用例

        CompanyDao companyDao = new CompanyDaoImpl();

        Company company1 = new Company();
        company1.name = "技術評論社";
        company1.address = new Address("東京都新宿区市谷左内町21-13");
        company1.phoneNumber = new PhoneNumber("03-3513-6150");
        companyDao.insert(company1);

        Address address = new Address("東京都新宿区市谷左内町21-13");
        Optional<PhoneNumber> phoneNumber = companyDao.selectPhoneNumberByAddress(address);

        out.println("**** 3 *******************************");
        out.printf("電話番号：%s%n", phoneNumber.map(PhoneNumber::getValue).orElse(""));
        out.println("**************************************");
    }

    /**
     * 必要なテーブルを作成してテストデータを投入します。
     * 
     * @throws SQLException
     */
    private static void setUpDB() throws SQLException {
        try (Connection con = DriverManager.getConnection(
                "jdbc:h2:mem:sample;DB_CLOSE_DELAY=-1", "sa", "mypassword");
                Statement st = con.createStatement()) {

            st.executeUpdate(
                    "CREATE TABLE Person (id BIGINT PRIMARY KEY, name VARCHAR(50), birthday DATE)");

            st.executeUpdate(
                    "CREATE TABLE Company (name VARCHAR(100), address VARCHAR(500), phoneNumber VARCHAR(20))");

            st.executeUpdate("INSERT INTO Person (id, name) VALUES (100, 'うらがみ')");
        }
    }
}
