package sample.dao;

import org.seasar.doma.Dao;
import org.seasar.doma.Delete;
import org.seasar.doma.Insert;
import org.seasar.doma.Select;
import org.seasar.doma.Update;

import sample.config.MyConfig;
import sample.entity.Person;

/**
 * Personテーブルのデータを操作をするDAOです。
 *
 */
@Dao(config = MyConfig.class)
public interface PersonDao {

    /**
     * idで検索します。
     * 
     * @param id id
     * @return 検索結果。ヒットしなかったらnullが返る。
     */
    @Select
    Person selectById(Long id);

    /**
     * PersonをINSERTします。
     * 
     * @param entity INSERTするデータ
     * @return INSERTされた件数
     */
    @Insert
    int insert(Person entity);

    /**
     * PersonをUPDATEします。
     * 
     * @param entity INSERTするデータ
     * @return UPDATEされた件数
     */
    @Update
    int update(Person entity);

    /**
     * PersonをDELETEします。
     * 
     * @param entity INSERTするデータ
     * @return DELETEされた件数
     */
    @Delete
    int delete(Person entity);
}